@@ -145,6 +145,7 @@ TargetDbTypeType = Literal["multiple-databases", "specific-database"]
 TestConnectionSucceedsWaiterName = Literal["test_connection_succeeds"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -177,6 +178,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
