@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -229,7 +229,7 @@ AddTagsToResourceMessageRequestTypeDef = TypedDict(
     "AddTagsToResourceMessageRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -321,7 +321,7 @@ _OptionalCreateEndpointMessageRequestTypeDef = TypedDict(
         "DatabaseName": str,
         "ExtraConnectionAttributes": str,
         "KmsKeyId": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "CertificateArn": str,
         "SslMode": DmsSslModeValueType,
         "ServiceAccessRoleArn": str,
@@ -374,10 +374,10 @@ _OptionalCreateEventSubscriptionMessageRequestTypeDef = TypedDict(
     "_OptionalCreateEventSubscriptionMessageRequestTypeDef",
     {
         "SourceType": str,
-        "EventCategories": List[str],
-        "SourceIds": List[str],
+        "EventCategories": Sequence[str],
+        "SourceIds": Sequence[str],
         "Enabled": bool,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -409,14 +409,14 @@ _OptionalCreateReplicationInstanceMessageRequestTypeDef = TypedDict(
     "_OptionalCreateReplicationInstanceMessageRequestTypeDef",
     {
         "AllocatedStorage": int,
-        "VpcSecurityGroupIds": List[str],
+        "VpcSecurityGroupIds": Sequence[str],
         "AvailabilityZone": str,
         "ReplicationSubnetGroupIdentifier": str,
         "PreferredMaintenanceWindow": str,
         "MultiAZ": bool,
         "EngineVersion": str,
         "AutoMinorVersionUpgrade": bool,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "KmsKeyId": str,
         "PubliclyAccessible": bool,
         "DnsNameServers": str,
@@ -446,13 +446,13 @@ _RequiredCreateReplicationSubnetGroupMessageRequestTypeDef = TypedDict(
     {
         "ReplicationSubnetGroupIdentifier": str,
         "ReplicationSubnetGroupDescription": str,
-        "SubnetIds": List[str],
+        "SubnetIds": Sequence[str],
     },
 )
 _OptionalCreateReplicationSubnetGroupMessageRequestTypeDef = TypedDict(
     "_OptionalCreateReplicationSubnetGroupMessageRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -491,7 +491,7 @@ _OptionalCreateReplicationTaskMessageRequestTypeDef = TypedDict(
         "CdcStartTime": Union[datetime, str],
         "CdcStartPosition": str,
         "CdcStopPosition": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "TaskData": str,
         "ResourceIdentifier": str,
     },
@@ -662,7 +662,7 @@ DescribeApplicableIndividualAssessmentsResponseTypeDef = TypedDict(
 DescribeCertificatesMessageRequestTypeDef = TypedDict(
     "DescribeCertificatesMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -681,7 +681,7 @@ DescribeCertificatesResponseTypeDef = TypedDict(
 DescribeConnectionsMessageRequestTypeDef = TypedDict(
     "DescribeConnectionsMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -732,7 +732,7 @@ DescribeEndpointSettingsResponseTypeDef = TypedDict(
 DescribeEndpointTypesMessageRequestTypeDef = TypedDict(
     "DescribeEndpointTypesMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -751,7 +751,7 @@ DescribeEndpointTypesResponseTypeDef = TypedDict(
 DescribeEndpointsMessageRequestTypeDef = TypedDict(
     "DescribeEndpointsMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -771,7 +771,7 @@ DescribeEventCategoriesMessageRequestTypeDef = TypedDict(
     "DescribeEventCategoriesMessageRequestTypeDef",
     {
         "SourceType": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -788,7 +788,7 @@ DescribeEventSubscriptionsMessageRequestTypeDef = TypedDict(
     "DescribeEventSubscriptionsMessageRequestTypeDef",
     {
         "SubscriptionName": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -812,8 +812,8 @@ DescribeEventsMessageRequestTypeDef = TypedDict(
         "StartTime": Union[datetime, str],
         "EndTime": Union[datetime, str],
         "Duration": int,
-        "EventCategories": List[str],
-        "Filters": List["FilterTypeDef"],
+        "EventCategories": Sequence[str],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -851,7 +851,7 @@ DescribePendingMaintenanceActionsMessageRequestTypeDef = TypedDict(
     "DescribePendingMaintenanceActionsMessageRequestTypeDef",
     {
         "ReplicationInstanceArn": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "Marker": str,
         "MaxRecords": int,
     },
@@ -918,7 +918,7 @@ DescribeReplicationInstanceTaskLogsResponseTypeDef = TypedDict(
 DescribeReplicationInstancesMessageRequestTypeDef = TypedDict(
     "DescribeReplicationInstancesMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -937,7 +937,7 @@ DescribeReplicationInstancesResponseTypeDef = TypedDict(
 DescribeReplicationSubnetGroupsMessageRequestTypeDef = TypedDict(
     "DescribeReplicationSubnetGroupsMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -976,7 +976,7 @@ DescribeReplicationTaskAssessmentResultsResponseTypeDef = TypedDict(
 DescribeReplicationTaskAssessmentRunsMessageRequestTypeDef = TypedDict(
     "DescribeReplicationTaskAssessmentRunsMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -995,7 +995,7 @@ DescribeReplicationTaskAssessmentRunsResponseTypeDef = TypedDict(
 DescribeReplicationTaskIndividualAssessmentsMessageRequestTypeDef = TypedDict(
     "DescribeReplicationTaskIndividualAssessmentsMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
     },
@@ -1014,7 +1014,7 @@ DescribeReplicationTaskIndividualAssessmentsResponseTypeDef = TypedDict(
 DescribeReplicationTasksMessageRequestTypeDef = TypedDict(
     "DescribeReplicationTasksMessageRequestTypeDef",
     {
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxRecords": int,
         "Marker": str,
         "WithoutSettings": bool,
@@ -1073,7 +1073,7 @@ _OptionalDescribeTableStatisticsMessageRequestTypeDef = TypedDict(
     {
         "MaxRecords": int,
         "Marker": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
     },
     total=False,
 )
@@ -1251,7 +1251,7 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
         "Name": str,
-        "Values": List[str],
+        "Values": Sequence[str],
     },
 )
 
@@ -1283,7 +1283,7 @@ _OptionalImportCertificateMessageRequestTypeDef = TypedDict(
     {
         "CertificatePem": str,
         "CertificateWallet": Union[bytes, IO[bytes], StreamingBody],
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1349,7 +1349,7 @@ ListTagsForResourceMessageRequestTypeDef = TypedDict(
     "ListTagsForResourceMessageRequestTypeDef",
     {
         "ResourceArn": str,
-        "ResourceArnList": List[str],
+        "ResourceArnList": Sequence[str],
     },
     total=False,
 )
@@ -1453,7 +1453,7 @@ _OptionalModifyEventSubscriptionMessageRequestTypeDef = TypedDict(
     {
         "SnsTopicArn": str,
         "SourceType": str,
-        "EventCategories": List[str],
+        "EventCategories": Sequence[str],
         "Enabled": bool,
     },
     total=False,
@@ -1487,7 +1487,7 @@ _OptionalModifyReplicationInstanceMessageRequestTypeDef = TypedDict(
         "AllocatedStorage": int,
         "ApplyImmediately": bool,
         "ReplicationInstanceClass": str,
-        "VpcSecurityGroupIds": List[str],
+        "VpcSecurityGroupIds": Sequence[str],
         "PreferredMaintenanceWindow": str,
         "MultiAZ": bool,
         "EngineVersion": str,
@@ -1518,7 +1518,7 @@ _RequiredModifyReplicationSubnetGroupMessageRequestTypeDef = TypedDict(
     "_RequiredModifyReplicationSubnetGroupMessageRequestTypeDef",
     {
         "ReplicationSubnetGroupIdentifier": str,
-        "SubnetIds": List[str],
+        "SubnetIds": Sequence[str],
     },
 )
 _OptionalModifyReplicationSubnetGroupMessageRequestTypeDef = TypedDict(
@@ -1670,7 +1670,7 @@ OracleSettingsTypeDef = TypedDict(
         "AddSupplementalLogging": bool,
         "ArchivedLogDestId": int,
         "AdditionalArchivedLogDestId": int,
-        "ExtraArchivedLogDestIds": List[int],
+        "ExtraArchivedLogDestIds": Sequence[int],
         "AllowSelectNestedTables": bool,
         "ParallelAsmReadThreads": int,
         "ReadAheadBlocks": int,
@@ -1785,6 +1785,7 @@ _OptionalRebootReplicationInstanceMessageRequestTypeDef = TypedDict(
     "_OptionalRebootReplicationInstanceMessageRequestTypeDef",
     {
         "ForceFailover": bool,
+        "ForcePlannedFailover": bool,
     },
     total=False,
 )
@@ -1898,7 +1899,7 @@ _RequiredReloadTablesMessageRequestTypeDef = TypedDict(
     "_RequiredReloadTablesMessageRequestTypeDef",
     {
         "ReplicationTaskArn": str,
-        "TablesToReload": List["TableToReloadTypeDef"],
+        "TablesToReload": Sequence["TableToReloadTypeDef"],
     },
 )
 _OptionalReloadTablesMessageRequestTypeDef = TypedDict(
@@ -1928,7 +1929,7 @@ RemoveTagsFromResourceMessageRequestTypeDef = TypedDict(
     "RemoveTagsFromResourceMessageRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -2186,8 +2187,8 @@ _OptionalStartReplicationTaskAssessmentRunMessageRequestTypeDef = TypedDict(
         "ResultLocationFolder": str,
         "ResultEncryptionMode": str,
         "ResultKmsKeyArn": str,
-        "IncludeOnly": List[str],
-        "Exclude": List[str],
+        "IncludeOnly": Sequence[str],
+        "Exclude": Sequence[str],
     },
     total=False,
 )
